<?php
/**
 * A unique identifier is defined to store the options in the database and reference them from the theme.
 * By default it uses the theme name, in lowercase and without spaces, but this can be changed if needed.
 * If the identifier changes, it'll appear as if the options have been reset.
 */

function optionsframework_option_name() {

	// This gets the theme name from the stylesheet
	$themename = wp_get_theme();
	$themename = preg_replace("/\W/", "_", strtolower($themename) );

	$optionsframework_settings = get_option( 'optionsframework' );
	$optionsframework_settings['id'] = $themename;
	update_option( 'optionsframework', $optionsframework_settings );
}

/**
 * Defines an array of options that will be used to generate the settings page and be saved in the database.
 * When creating the 'id' fields, make sure to use all lowercase and no spaces.
 *
 * If you are making your theme translatable, you should replace 'options_framework_theme'
 * with the actual text domain for your theme.  Read more:
 * http://codex.wordpress.org/Function_Reference/load_theme_textdomain
 */

function optionsframework_options() {

	

	// Pull all the categories into an array
	$options_categories = array();
	$options_categories_obj = get_categories();
	foreach ($options_categories_obj as $category) {
		$options_categories[$category->cat_ID] = $category->cat_name;
	}

	// Pull all tags into an array
	$options_tags = array();
	$options_tags_obj = get_tags();
	foreach ( $options_tags_obj as $tag ) {
		$options_tags[$tag->term_id] = $tag->name;
	}


	// Pull all the pages into an array
	$options_pages = array();
	$options_pages_obj = get_pages('sort_column=post_parent,menu_order');
	$options_pages[''] = 'Select a page:';
	foreach ($options_pages_obj as $page) {
		$options_pages[$page->ID] = $page->post_title;
	}

	// If using image radio buttons, define a directory path
	$imagepath =  get_template_directory_uri() . '/images/';

	$options = array();

	$options[] = array(
		'name' => __('Front-Page Settings', 'options_framework_theme'),
		'type' => 'heading');

	$options[] = array(
		'name' => __('Core Competency 1 Text Editor', 'options_framework_theme'),
		'desc' => sprintf( __( 'This should include a heading 3 and a short bit of text about one of your company\'s primary offerings. Let visitors know what you are good at and consider adding a Read More... link.  ', 'options_framework_theme' ), 'http://codex.wordpress.org/Function_Reference/wp_editor' ),
		'id' => 'cc1_editor',
		'std' => '<h3>Core Competency1</h3><p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laboru</p>',
		'type' => 'editor',
		'settings' => $wp_editor_settings );
		
	$options[] = array(
		'name' => __('Core Competency 2 Text Editor', 'options_framework_theme'),
		'desc' => sprintf( __( 'This should include a heading 3 and a short bit of text about one of your company\'s primary offerings. Let visitors know what you are good at and consider adding a Read More... link.  ', 'options_framework_theme' ), 'http://codex.wordpress.org/Function_Reference/wp_editor' ),
		'id' => 'cc2_editor',
		'std' => '<h3>Core Competency2</h3><p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laboru</p>',
		'type' => 'editor',
		'settings' => $wp_editor_settings );

	$options[] = array(
		'name' => __('Core Competency 3 Text Editor', 'options_framework_theme'),
		'desc' => sprintf( __( 'This should include a heading 3 and a short bit of text about one of your company\'s primary offerings. Let visitors know what you are good at and consider adding a Read More... link.  ', 'options_framework_theme' ), 'http://codex.wordpress.org/Function_Reference/wp_editor' ),
		'id' => 'cc3_editor',
		'std' => '<h3>Core Competency3</h3><p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laboru</p>',
		'type' => 'editor',
		'settings' => $wp_editor_settings );

	$options[] = array(
		'name' => __('Header Settings', 'options_framework_theme'),
		'type' => 'heading');

	$options[] = array(
		'name' => __('Logo Uploader', 'options_framework_theme'),
		'desc' => __('Upload your logo to this theme. It will appear in the top left corner.', 'options_framework_theme'),
		'id' => 'logo_uploader',
		'std' => ''.$imagepath.'logo.gif',
		'type' => 'upload');

	$options[] = array(
		'name' => __('Logo Vertical Position', 'options_framework_theme'),
		'desc' => __('Alter the vertical position of your logo image.', 'options_framework_theme'),
		'id' => 'logo_margin',
		'std' => '-25',
		'type' => 'text');

	$options[] = array(
		'name' => __('Uploader Marketing Message', 'options_framework_theme'),
		'desc' => __('Upload your main marketing image. This will appear beside the contact form.', 'options_framework_theme'),
		'id' => 'marketing_uploader',
		'std' => ''.$imagepath.'slider-cat.png',
		'type' => 'upload');

	$options[] = array(
		'name' => __('Social Media Text Editor', 'options_framework_theme'),
		'desc' => sprintf( __( 'This is to edit the social media icons at the center-top of your website.', 'options_framework_theme' ), 'http://codex.wordpress.org/Function_Reference/wp_editor' ),
		'id' => 'social_media_editor',
		'std' => 'Follow us on:
		<a href="http://www.facebook.com" target="_blank"><img src="'.$imagepath.'facebook.png" alt="Facebook" /></a>
		<a href="https://linkedin.com" target="_blank" ><img src="'.$imagepath.'linkedin.png" alt="LinkedIn" /></a>
		<a href="https://youtube.com" target="_blank" ><img src="'.$imagepath.'googleplus.png" alt="Google+" /></a>
		',
		'type' => 'editor',
		'settings' => $wp_editor_settings );

	$options[] = array(
		'name' => __('Phone Number Text Editor', 'options_framework_theme'),
		'desc' => sprintf( __( 'This is to change the phone number text at the top-right of your website', 'options_framework_theme' ), 'http://codex.wordpress.org/Function_Reference/wp_editor' ),
		'id' => 'phone_editor',
		'std' => 'Call Us!: 123-456-7890<h5>Or email: <a href="mailto:example@example.ca">example@example.ca</a></h5>',
		'type' => 'editor',
		'settings' => $wp_editor_settings );

	$options[] = array(
		'name' => __('Contact Form Settings', 'options_framework_theme'),
		'type' => 'heading' );

	/**
	 * For $settings options see:
	 * http://codex.wordpress.org/Function_Reference/wp_editor
	 *
	 * 'media_buttons' are not supported as there is no post to attach items to
	 * 'textarea_name' is set by the 'id' you choose
	 */

	$wp_editor_settings = array(
		'wpautop' => true, // Default
		'textarea_rows' => 5,
		'tinymce' => array( 'plugins' => 'wordpress' )
	);



	$options[] = array(
		'name' => __('Contact Form Text Settings', 'options_framework_theme'),
		'desc' => sprintf( __( 'This should be used with the Contact Form 7 Plugin. Give this form a heading 2 title and paste in your Contact Form 7 shortcode ', 'options_framework_theme' ), 'http://codex.wordpress.org/Function_Reference/wp_editor' ),
		'id' => 'form_editor',
		'std' => '<strong>Insert your contact form shortcode here!</strong>',
		'type' => 'editor',
		'settings' => $wp_editor_settings );


	$options[] = array(
		'name' => __('Footer Content Editor', 'options_framework_theme'),
		'type' => 'heading' );

	$options[] = array(
		'name' => __('Footer Text Editor', 'options_framework_theme'),
		'desc' => sprintf( __( 'This is to change the text at the bottom of your website', 'options_framework_theme' ), 'http://codex.wordpress.org/Function_Reference/wp_editor' ),
		'id' => 'footer_editor',
		'std' => '<p style="text-align: center;">Copyright © 2014. <span>&nbsp;</span> All Rights Reserved. | <a href="mailto:example@example.ca">Contact Email</a> | <a href="http://www.example.ca/sitemap">Sitemap</a></p>
',
		'type' => 'editor',
		'settings' => $wp_editor_settings );


	$options[] = array(
		'name' => __('Front-Page Settings', 'options_framework_theme'),
		'type' => 'heading');

	$options[] = array(
		'name' => __('Contact Form Text Settings', 'options_framework_theme'),
		'desc' => sprintf( __( 'This should be used with the Contact Form 7 Plugin. Give this form a heading 2 title and paste in your Contact Form 7 shortcode. It is reccomended to use a different form than other pages, perhaps with more fields. ', 'options_framework_theme' ), 'http://codex.wordpress.org/Function_Reference/wp_editor' ),
		'id' => 'ppc_form_editor',
		'std' => '<strong>Insert your contact form shortcode for your Pay-Per-Click campaign here!</strong>',
		'type' => 'editor',
		'settings' => $wp_editor_settings );

	$options[] = array(
		'name' => __('Phone Number Text Editor', 'options_framework_theme'),
		'desc' => sprintf( __( 'This is to change the phone number text at the top-right of your landing page. Consider getting a unique tracking number from Phone.com to log phone calls.', 'options_framework_theme' ), 'http://codex.wordpress.org/Function_Reference/wp_editor' ),
		'id' => 'ppc_phone_editor',
		'std' => 'Call Us!: 1-800-456-7890<h5>Or email: <a href="mailto:unique4ppc@example.ca">unique4ppc@example.ca</a></h5>',
		'type' => 'editor',
		'settings' => $wp_editor_settings );


	return $options;
}